@@ -12,6 +12,13 @@ parser.add_argument(
     metavar="TOKEN",
     help="setup local config file and database. optionally accepts a hydrant's api token",
 )
+parser.add_argument(
+    "--systemd",
+    nargs="?",
+    const="",
+    metavar="LOCATION",
+    help="move the digital-hydrant service file to it's system location (defaults to /usr/lib/systemd/system/)",
+)
 parser.add_argument(
     "-c",
     "--collect",
