@@ -28,6 +28,7 @@ class CollectorQueue:
     def __init__(self):
         self.logger = logging.getLogger(__name__)
         self.__table__ = "collectors"
+        self.__ip_table__ = "unique_ips"
         self.logger.debug("CollectorQueue initialized")
 
         try:
@@ -48,11 +49,53 @@ class CollectorQueue:
         finally:
             self.conn.commit()
 
+    def put_ip(self, ip, mac):
+        try:
+            query = f"INSERT INTO {self.__ip_table__}(ip, mac_address) VALUES('{ip}', '{mac}')"
+            self.logger.debug(query)
+            self.cursor.execute(query)
+        except sqlite3.Error as e:
+            if isinstance(e, sqlite3.IntegrityError):
+                self.logger.debug(
+                    f"IP({ip}) already exists in {self.__ip_table__}: {e}"
+                )
+            else:
+                self.logger.critical(
+                    f"Failed to insert IP({ip})/macAddress({mac}) into table: {e}"
+                )
+        finally:
+            self.conn.commit()
+
     def peak(self):
-        query = f"SELECT id, type, payload, timestamp FROM {self.__table__} WHERE uploaded=0 ORDER BY id ASC"
+        query = f"SELECT id, type, payload, timestamp FROM {self.__table__} WHERE uploaded=0 ORDER BY id ASC LIMIT 500"
+        self.cursor.execute(query)
+        return self.cursor.fetchall()
+
+    def find_ip(self, ip):
+        query = f"SELECT id, ip, mac_address FROM {self.__ip_table__} WHERE ip = '{ip}'"
         self.cursor.execute(query)
         return self.cursor.fetchone()
 
+    def update_ip(self, ip, changes={}):
+        try:
+            set = ""
+            for column, value in changes.items():
+                if isinstance(value, str):
+                    value = f"'{value}'"
+                if value is None:
+                    value = "NULL"
+
+                set += f"{column}={value}" if len(set) == 0 else f", {column}={value}"
+
+            if set:
+                self.cursor.execute(
+                    f"UPDATE {self.__ip_table__} SET {set} WHERE ip='{ip}'"
+                )
+        except sqlite3.Error as e:
+            self.logger.error(f"Failed to update {self.__ip_table__} for {ip}: {e}")
+        finally:
+            self.conn.commit()
+
     def pop(self, delete=True):
         (id) = self.peak()
         self.remove(id, delete)
@@ -85,9 +128,12 @@ class CollectorQueue:
         finally:
             self.conn.commit()
 
-    def fail(self, id):
+    def fail(self, id, message=""):
         try:
-            self.cursor.execute(f"UPDATE {self.__table__} SET uploaded=2 WHERE ID={id}")
+            error = f", upload_error='{message}'" if message != "" else ""
+            self.cursor.execute(
+                f"UPDATE {self.__table__} SET uploaded=2{error} WHERE ID={id}"
+            )
         except sqlite3.Error as e:
             self.logger.error(f"Failed to update uploaded=2 from table: {e}")
         finally:
