@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU General Public License
 # along with Digital-Hydrant.  If not, see https://www.gnu.org/licenses/.
 
-import time
 from datetime import datetime
 
 from digital_hydrant.collectors.collector import Collector
@@ -26,9 +25,24 @@ class Dhcp(Collector):
 
     def run(self):
         timestamp = datetime.timestamp(datetime.now()) * 1000
-        command = "dhcpcd -T 2> /dev/null | tr '\n' ' '"
-        output = self.execute(command)
+
+        output = self.execute("dhcpcd -T 2> /dev/null")
+        output = output.replace("'", "")
+
         payload = {"dhcp_log": output}
+
+        for data in output.split("\n"):
+            divider = "=" if "=" in data else ":"
+            splits = data.split(divider)
+            if len(splits) == 2:
+                key = splits[0].strip()
+                value = splits[1].strip()
+                previous = payload[key] if key in payload else ""
+                if previous == value:
+                    continue
+
+                payload[key] = (previous + " " + value).strip()
+
         self.queue.put(
             **{"type": self.name, "payload": payload, "timestamp": timestamp}
         )
