@@ -51,8 +51,8 @@ class Hydra(Collector):
             self.name, "interface", fallback="wlan0"
         )
 
-        self.wordlist_path = pkg_resources.resource_filename(
-            "digital_hydrant", "config/hydra/wordlist.txt"
+        self.passwords_path = pkg_resources.resource_filename(
+            "digital_hydrant", "config/hydra/common-passwords.txt"
         )
         self.userlist_path = pkg_resources.resource_filename(
             "digital_hydrant", "config/hydra/userlist.txt"
@@ -77,7 +77,7 @@ class Hydra(Collector):
                 )
 
         self.cursor.execute(
-            f"SELECT ip, open_ports FROM {self.table_name} WHERE {where} ORDER BY {order_by} ASC"
+            f"SELECT ip, open_ports, mac_address FROM {self.table_name} WHERE {where} ORDER BY {order_by} ASC"
         )
 
         records = self.cursor.fetchall()
@@ -89,6 +89,7 @@ class Hydra(Collector):
     def __hydra__(self, record):
         ip = record[0]
         ports = record[1]
+        mac_address = record[2]
 
         # connect to subnet, use X.X.X.227 because it is rarely used
         my_subnet_ip = "{}.227".format(re.sub(r"\.\d+$", "", ip))
@@ -97,13 +98,14 @@ class Hydra(Collector):
 
         parsed_output = {}
         parsed_output["target"] = ip
+        parsed_output["mac_address"] = mac_address
 
         ssh_output = ""
         snmp_output = ""
 
         run_ssh = self.ssh_enabled and PORTS["ssh"] in ports
         if run_ssh:
-            ssh_command = f"hydra -I -L {self.userlist_path} -P {self.wordlist_path} {ip} ssh 2>&1"
+            ssh_command = f"hydra -I -L {self.userlist_path} -P {self.passwords_path} {ip} ssh 2>&1"
             ssh_output = self.execute(ssh_command)
 
             parsed_output["ssh"] = self.parse_output(ssh_output)
@@ -111,6 +113,9 @@ class Hydra(Collector):
 
         run_snmp = self.snmp_enabled and PORTS["snmp"] in ports
         if run_snmp:
+            snmp_command = f"hydra -I -P {self.snmp_wordlist_path} {ip} snmp 2>&1"
+            snmp_output = self.execute(snmp_command)
+
             parsed_output["snmp"] = self.parse_output(snmp_output)
             parsed_output["snmp_output_log"] = snmp_output
 
@@ -128,26 +133,15 @@ class Hydra(Collector):
         self.logger.debug(f"Disconnecting from {ip}")
         self.execute(f"ifconfig {self.iface}:1 down")
 
-        try:
-            set = ""
-            if run_ssh:
-                set += f"ssh_last_tested={timestamp}"
+        set = {}
+        if run_ssh:
+            set["ssh_last_tested"] = timestamp
 
-            if run_snmp:
-                set += (
-                    f"snmp_last_tested={timestamp}"
-                    if len(set) == 0
-                    else f", snmp_last_tested={timestamp}"
-                )
+        if run_snmp:
+            set["snmp_last_tested"] = timestamp
 
-            if set:
-                self.cursor.execute(
-                    f"UPDATE {self.table_name} SET {set} WHERE ip='{ip}'"
-                )
-        except sqlite3.Error as e:
-            self.logger.error(f"Failed to update last_tested for {ip}: {e}")
-        finally:
-            self.conn.commit()
+        if set:
+            self.queue.update_ip(ip, set)
 
     def parse_output(self, output):
         data = {}
