@@ -56,11 +56,14 @@ class Netdiscover(Collector):
             ["--localnet"] if subnet_config == "--localnet" else common_subnets
         )
 
+        interval = config.get("netdiscover", "interval", fallback="")
         for subnet in common_subnets:
             subnet = subnet + subnet_config if not "--" in subnet else subnet
             self.logger.debug(f"Scanning {subnet} with arp-scan")
 
-            output = self.execute(f"arp-scan {subnet}")
+            cmd = f"arp-scan {subnet}"
+            cmd += f" --interval={interval}" if interval else ""
+            output = self.execute(cmd)
             for line in output.split("\n"):
                 self.parse_line(line)
 
@@ -101,3 +104,19 @@ class Netdiscover(Collector):
         self.queue.put(
             **{"type": self.name, "payload": parsed_output, "timestamp": timestamp}
         )
+
+        existing = self.queue.find_ip(parsed_output["ip"])
+
+        if existing and existing[2] != parsed_output["mac_address"]:
+            self.queue.update_ip(
+                parsed_output["ip"],
+                {
+                    "mac_address": parsed_output["mac_address"],
+                    "ssh_last_tested": None,
+                    "snmp_last_tested": None,
+                    "last_nmap_scan": None,
+                    "open_ports": None,
+                },
+            )
+        elif not existing:
+            self.queue.put_ip(parsed_output["ip"], parsed_output["mac_address"])
