@@ -17,6 +17,8 @@
 import shutil
 import sys
 
+import pkg_resources
+
 from digital_hydrant import logging
 from digital_hydrant.args import args
 from digital_hydrant.collector_queue import CollectorQueue
@@ -57,11 +59,21 @@ def run():
     check_default_config()
     migrate_db()
 
-    # Initialize the CollectorQueue singleton before we start creating processes
+    # Initialize the CollectorQueue singleton
     CollectorQueue.instance()
 
     missing = False if args.force else check_required_ubuntu_packages()
 
+    if args.systemd is not None:
+        service_path = pkg_resources.resource_filename(
+            "digital_hydrant", "systemd/digital-hydrant.service"
+        )
+        target = args.systemd if len(args.systemd) > 0 else "/usr/lib/systemd/system"
+
+        shutil.copy(service_path, target)
+        print("\nsystemd ready to use")
+        return
+
     if args.init is not None:
         if len(args.init) > 0:
             update_config({"api": {"token": args.init}})
