@@ -20,23 +20,63 @@ import uuid
 import importlib
 from urllib.error import HTTPError
 import socket
-
+import subprocess
 import requests
 
 from digital_hydrant import logging
 import digital_hydrant.config
-from digital_hydrant.server_data_processor import Processor
 from digital_hydrant.__version__ import version
+from digital_hydrant.commands import shutdown, restart
 
 
 class Ping:
     def __init__(self):
         self.logger = logging.getLogger(__name__)
         self.mac_addr = ":".join(re.findall("..", "%012x" % uuid.getnode()))
-        self.processor = Processor()
 
         self.api_token = digital_hydrant.config.config.get("api", "token")
         self.api_url = digital_hydrant.config.config.get("api", "url")
+        self.first_ping = True
+
+    def get_system_details(self):
+        self.first_ping = False
+        public_ip = requests.get("https://api.ipify.org").text
+        private_ip = "127.0.0.1"
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        try:
+            s.connect(("10.255.255.255", 1))
+            private_ip = s.getsockname()[0]
+        except Exception as err:
+            pass
+        finally:
+            s.close()
+
+        details = {
+            "publicIp": public_ip,
+            "privateIp": private_ip,
+            "version": version,
+        }
+
+        options = {
+            "s": "kernelName",
+            "n": "nodename",
+            "r": "kernelRelease",
+            "v": "kernelVersion",
+            "m": "machine",
+            "p": "processor",
+            "i": "hardware",
+            "o": "operatingSystem",
+        }
+
+        for option, name in options.items():
+            output = subprocess.run(
+                f"uname -{option}", shell=True, stdout=subprocess.PIPE
+            ).stdout.decode("utf-8")
+
+            if output:
+                details[name] = output.strip("\n")
+
+        return details
 
     def __exec__(self):
         while True:
@@ -51,35 +91,18 @@ class Ping:
             self.logger.info("Ping server")
 
             try:
-                public_ip = requests.get("https://api.ipify.org").text
-                private_ip = "127.0.0.1"
-                s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-                try:
-                    s.connect(("10.255.255.255", 1))
-                    private_ip = s.getsockname()[0]
-                finally:
-                    s.close()
+                details = self.get_system_details() if self.first_ping else {}
 
                 headers = {"Authorization": f"Bearer {self.api_token}"}
                 response = requests.put(
                     f"{self.api_url}/ping",
-                    json={
-                        "public_ip": public_ip,
-                        "private_ip": private_ip,
-                        "version": version,
-                    },
+                    json=details,
                     headers=headers,
                 )
                 response.raise_for_status()
 
                 response_data = response.json()
 
-                # handle new data from the server
-                if "data" in response_data.keys() and isinstance(
-                    response_data["data"], dict
-                ):
-                    self.processor.process_server_data(response_data["data"])
-
                 params = None
                 # handle new config from the server
                 if "config" in response_data.keys() and isinstance(
@@ -99,12 +122,29 @@ class Ping:
 
                         params[section] = temp_dict
 
-                requests.put(
+                complete_response = requests.put(
                     f"{self.api_url}/ping/complete", json=params, headers=headers
                 )
+                complete_response.raise_for_status()
+
+                if "commandQueue" in response_data.keys() and isinstance(
+                    response_data["commandQueue"], list
+                ):
+                    for command in response_data["commandQueue"]:
+                        if command["type"] == "shutdown":
+                            shutdown()
+                        elif command["type"] == "restart":
+                            restart()
+
             except requests.exceptions.ConnectionError:
                 self.logger.error("Network error on ping")
 
-            except HTTPError as e:
-                self.logger.error(f"Failed to ping server\n\n{e}")
+            except requests.exceptions.HTTPError as e:
+                if e.response.status_code == 429:
+                    res = e.response.json()
+                    if "msBeforeNext" in res:
+                        sleep = res["msBeforeNext"] / 1000
+                        if sleep > self.wait:
+                            time.sleep(sleep)
+                self.logger.error(f"Failed to ping server\n{e}")
             time.sleep(self.wait)
