@@ -108,11 +108,12 @@ class ProcessManager:
 
         for section in previous_details.keys():
             if self.is_scheduled(section):
-                self.scheduler.cancel_job(self.jobs[name])
-                self.jobs.pop(name, None)
-                if name in self.processes and self.processes[name].is_alive():
-                    self.processes[name].terminate()
-                    self.processes.pop(name, None)
+                self.scheduler.cancel_job(self.jobs[section])
+                self.jobs.pop(section, None)
+                self.process_details.pop(section, None)
+                if section in self.processes and self.processes[section].is_alive():
+                    self.processes[section].terminate()
+                    self.processes.pop(section, None)
 
                 self.logger.info(f"Removed {section}")
 
