@@ -53,31 +53,52 @@ class Uploader:
 
             # select all un-uploaded data entries and add to queue
             self.logger.debug("Scanning database for unprocessed entries")
-            entry = self.queue.peak()
+            entries = self.queue.peak()
 
-            if entry is None:
+            if len(entries) == 0:
                 time.sleep(5)
             else:
-                (id, type, payload, timestamp) = entry
+                data = []
+                ids = []
+                for entry in entries:
+                    (id, type, payload, timestamp) = entry
+                    data.append(
+                        {
+                            "source": str(self.mac_addr),
+                            "timestamp": timestamp,
+                            "type": type,
+                            "payload": payload,
+                        }
+                    )
+                    ids.append(id)
                 try:
-                    data = {
-                        "source": str(self.mac_addr),
-                        "timestamp": timestamp,
-                        "type": type,
-                        "payload": payload,
-                    }
+                    self.logger.info(f"Uploading {len(data)} entries")
+
                     headers = {"Authorization": f"Bearer {self.api_token}"}
                     response = requests.post(self.api_url, headers=headers, json=data)
-                    self.logger.info(f"Upload collector {type} at {timestamp}")
                     response.raise_for_status()
 
                     output = response.json()
 
-                    self.queue.remove(id)
+                    for i in range(len(data)):
+                        if not output["results"][i]["success"]:
+                            self.queue.fail(ids[i], output["results"][i]["message"])
+                        else:
+                            self.queue.remove(ids[i])
                 except requests.exceptions.ConnectionError:
                     self.logger.error("Network error, will retry in 30 seconds")
                     time.sleep(30)
 
                 except requests.exceptions.HTTPError as e:
-                    self.logger.error(f"Failed to upload data: {e}")
-                    self.queue.fail(id)
+                    if e.response.status_code == 429:
+                        res = e.response.json()
+                        if "msBeforeNext" in res:
+                            sleep = res["msBeforeNext"] / 1000
+                            self.logger.warn(
+                                f"Rate limit reached. Sleeping for {sleep} seconds"
+                            )
+                            time.sleep(sleep)
+                    else:
+                        self.logger.error(f"Failed to upload data: {e}")
+                    for id in ids:
+                        self.queue.fail(id)
