@@ -1,6 +1,9 @@
+import time
+
+
 class Hydra:
     def __init__(self, name):
         self.name = str(name)
 
     def run_collection(self):
-        pass
+        time.sleep(0.2)
